/** GUIBig10Mascots.java provides the class GUIBig10Mascots for building GUIs
 *    that users can use to find the mascots of Big-10 universities.
 *  @see Big10
 */

import ann.gui.CloseableFrame;
import javax.swing.*;            // JLabel, JTextField, JPanel
import java.awt.*;               // Color
import java.awt.event.*;         // ActionEvent, ...

class GUIBig10Mascots extends CloseableFrame
                      implements ActionListener
{
 /** GUI constructor.
  *  Postcondition: the GUI has been constructed
  */
 public GUIBig10Mascots()
 {
   setTitle("Big-10 University Mascots");

   mySchoolLabel = new JLabel("University: ", SwingConstants.RIGHT);
   mySchoolField = new JTextField(14);
   mySchoolField.addActionListener(this);

   myMascotLabel = new JLabel("Mascot: ", SwingConstants.RIGHT);
   myMascotLabel.setVisible(false);

   myMascotField = new JTextField(14);
   myMascotField.setVisible(false);
   myMascotField.setEditable(false);

   myPanel = new JPanel();
   myPanel.setLayout( new GridLayout(2,2) ); // 2 rows, 2 columns
   myPanel.add(mySchoolLabel);               // row 1 column 1
   myPanel.add(mySchoolField);               // row 1 column 2
   myPanel.add(myMascotLabel);               // row 2 column 1
   myPanel.add(myMascotField);               // row 2 column 2
   setContentPane(myPanel);
 }


 /** ActionEvent handler
  *  Receive:       event, an ActionEvent
  *  Precondition:  event was generated by an 'Enter' in mySchoolField
  *  Postcondition: event has been processed
  */
 public void actionPerformed(ActionEvent event)
 {
   String school = mySchoolField.getText();

   if (school.length() == 0)       // no text entered
   { 
     myMascotLabel.setVisible(false);
  myMascotField.setText("");
  myMascotField.setVisible(false);
   }
   else
   {
  String mascot = Big10.mascot(school);
  if (mascot.length() == 0)      // non-Big-10 school
  {
    myMascotLabel.setVisible(false);
    myMascotField.setText("Not in Big-10");
    myMascotField.setVisible(true);
  }
  else                           // all is well
  {
    myMascotLabel.setVisible(true);
    myMascotField.setText(mascot);
    myMascotField.setVisible(true);
  }
   } 
 }

 public static void main(String [] args)
 {
   GUIBig10Mascots aGUI = new GUIBig10Mascots();
   aGUI.setBackground(Color.white);
   aGUI.pack();
   aGUI.setVisible(true);
 }

 private JLabel     mySchoolLabel, myMascotLabel;
 private JTextField mySchoolField, myMascotField;
 private JPanel     myPanel;
}

